@@ -58,6 +58,9 @@ def get_args ():
 	                    choices=["centroid", "consistency"],
 	                    required=True,
 	                    default="centroid")
+	parser.add_argument("-c", "--cluster",
+	                   help='input the cluster file for protein families',
+	                   default=None)
 	parser.add_argument("-o", "--output",
 	                    help='output annotation detailed file for UniRef annotation',
 	                    required=True)
@@ -535,13 +538,17 @@ def main():
 	
 	### get arguments ###
 	values = get_args ()
+	myfamily = config.protein_family
+	if values.cluster:
+		myfamily = values.cluster
+
 
 	sys.stderr.write("### Start uniref_protein_family.py -m " + values.mapping + " ####\n")
 	
 
 	### collect cluster info ###
 	sys.stderr.write("Get cluster info ......starting\n")
-	pep_cluster = collect_peptide_cluster_info (config.protein_family)
+	pep_cluster = collect_peptide_cluster_info (myfamily)
 	sys.stderr.write("Get cluster info ......done\n")
 	
 	### collect annotation info ###
